==> ideaIC-15.0.3-sources.jar: com/intellij/openapi/module/impl/scopes/ModulesScope.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.module.impl.scopes;

import com.intellij.openapi.module.Module;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.roots.ProjectFileIndex;
import com.intellij.openapi.roots.ProjectRootManager;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.psi.search.GlobalSearchScope;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;

import java.util.Arrays;
import java.util.Set;

public class ModulesScope extends GlobalSearchScope {

  private final ProjectFileIndex myProjectFileIndex;
  private final Set<Module> myModules;

  public ModulesScope(@NotNull Set<Module> modules, Project project) {
    super(project);
    myProjectFileIndex = ProjectRootManager.getInstance(project).getFileIndex();
    myModules = modules;
  }

  @Override
  public boolean contains(@NotNull VirtualFile file) {
    Module moduleOfFile = myProjectFileIndex.getModuleForFile(file);
    return moduleOfFile != null && myModules.contains(moduleOfFile);
  }

  @Override
  public int compare(@NotNull VirtualFile file1, @NotNull VirtualFile file2) {
    return 0;
  }

  @Override
  public boolean isSearchInModuleContent(@NotNull Module aModule) {
    return myModules.contains(aModule);
  }

  @Override
  public boolean isSearchInLibraries() {
    return false;
  }

  @NonNls
  public String toString() {
    return "Modules:" + Arrays.toString(myModules.toArray(new Module[myModules.size()]));
  }
}

==> ideaIC-163.4396.1-sources.jar: com/intellij/openapi/module/impl/scopes/ModulesScope.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.module.impl.scopes;

import com.intellij.openapi.module.Module;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.roots.ProjectFileIndex;
import com.intellij.openapi.roots.ProjectRootManager;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.psi.search.GlobalSearchScope;
import org.jetbrains.annotations.NotNull;

import java.util.Arrays;
import java.util.Collections;
import java.util.Set;

public class ModulesScope extends GlobalSearchScope {
  private final ProjectFileIndex myProjectFileIndex;
  private final Set<Module> myModules;

  public ModulesScope(@NotNull Module module) {
    this(Collections.singleton(module), module.getProject());
  }

  public ModulesScope(@NotNull Set<Module> modules, @NotNull Project project) {
    super(project);
    myProjectFileIndex = ProjectRootManager.getInstance(project).getFileIndex();
    myModules = modules;
  }

  @Override
  public boolean contains(@NotNull VirtualFile file) {
    Module moduleOfFile = myProjectFileIndex.getModuleForFile(file);
    return moduleOfFile != null && myModules.contains(moduleOfFile);
  }

  @Override
  public int compare(@NotNull VirtualFile file1, @NotNull VirtualFile file2) {
    return 0;
  }

  @Override
  public boolean isSearchInModuleContent(@NotNull Module aModule) {
    return myModules.contains(aModule);
  }

  @Override
  public boolean isSearchInLibraries() {
    return false;
  }

  @Override
  public String toString() {
    return "Modules:" + Arrays.toString(myModules.toArray(new Module[myModules.size()]));
  }
}
